@@ -151,6 +151,34 @@ class InspectRequestsMixin:
     def param_overrides(self):
         self._client.clear_param_overrides()
 
+    @property
+    def body_overrides(self):
+        """The body overrides for outgoing browser requests.
+
+        For 'not GET' requests, the parameters are assumed to be encoded in the
+        request body.
+
+        The value of the body can be a string value or list of sublists,
+        with each sublist having two elements - a URL pattern and string value.
+        The string value will be encoded, then replace whole http body.
+        And body_overrides has higher priority than param_overrides When they conflict.
+        For example:
+            body_overrides = '{"foo":"bar"}'
+            body_overrides = [
+                ('.*somewhere.com.*', '{"foo":"bar"}'),
+                ('*.somewhere-else.com.*', '{"x":"y"}'),
+            ]
+        """
+        return self._client.get_body_overrides()
+
+    @body_overrides.setter
+    def body_overrides(self, bodies):
+        self._client.set_body_overrides(bodies)
+
+    @body_overrides.deleter
+    def body_overrides(self):
+        self._client.clear_body_overrides()
+
     @property
     def querystring_overrides(self):
         """The querystring overrides for outgoing browser requests.
