@@ -38,7 +38,10 @@ class BrowserIntegrationTest(TestCase):
 
     def test_chrome_can_access_requests(self):
         url = 'https://www.wikipedia.org/'
-        driver = webdriver.Chrome()
+        sw_options = {
+            'backend': 'mitmproxy'
+        }
+        driver = webdriver.Chrome(seleniumwire_options=sw_options)
         driver.get(url)
 
         request = driver.wait_for_request(url)
